#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 email-validate
version:              2.3.2.13
visibility:           public
id:                   email-validate-2.3.2.13-4Do5pTS423H5nxE3J1H2aZ
key:                  email-validate-2.3.2.13-4Do5pTS423H5nxE3J1H2aZ
license:              BSD-3-Clause
maintainer:           George Pollard <porges@porg.es>
author:               George Pollard <porges@porg.es>
stability:            experimental
homepage:             https://github.com/Porges/email-validate-hs
synopsis:             Email address validation
description:          Validating an email address string against RFC 5322
category:             Text
abi:                  6cb0c63415b511930574b07dd83a6361
exposed:              True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate

import-dirs:          /usr/lib/ghc-8.10.5/site-local/email-validate-2.3.2.13
library-dirs:         /usr/lib/ghc-8.10.5/site-local/email-validate-2.3.2.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/email-validate-2.3.2.13
hs-libraries:         HSemail-validate-2.3.2.13-4Do5pTS423H5nxE3J1H2aZ
depends:
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib base-4.14.2.0
    bytestring-0.10.12.0 template-haskell-2.16.0.0

haddock-interfaces:
    /usr/share/doc/haskell-email-validate/html/email-validate.haddock

haddock-html:         /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

